@@ -1,6 +1,6 @@
 package Dist::Zilla::MVP::Reader::Finder;
 # ABSTRACT: the reader for dist.ini files
-$Dist::Zilla::MVP::Reader::Finder::VERSION = '5.044';
+$Dist::Zilla::MVP::Reader::Finder::VERSION = '5.045';
 use Moose;
 use Config::MVP::Reader 2.101540; # if_none
 extends 'Config::MVP::Reader::Finder';
@@ -28,11 +28,11 @@ Dist::Zilla::MVP::Reader::Finder - the reader for dist.ini files
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
