@@ -1,55 +1,14 @@
 package Dist::Zilla::Plugin::AutoPrereqs;
 # ABSTRACT: automatically extract prereqs from your modules
-$Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.044';
+$Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.045';
 use Moose;
 with(
+  'Dist::Zilla::Role::PrereqScanner',
   'Dist::Zilla::Role::PrereqSource',
   'Dist::Zilla::Role::PPI',
-  'Dist::Zilla::Role::FileFinderUser' => {
-    default_finders => [ ':InstallModules', ':ExecFiles' ],
-  },
-  'Dist::Zilla::Role::FileFinderUser' => {
-    method           => 'found_test_files',
-    finder_arg_names => [ 'test_finder' ],
-    default_finders  => [ ':TestFiles' ],
-  },
-  'Dist::Zilla::Role::FileFinderUser' => {
-    method           => 'found_configure_files',
-    finder_arg_names => [ 'configure_finder' ],
-    default_finders  => [],
-  },
-  'Dist::Zilla::Role::FileFinderUser' => {
-    method           => 'found_develop_files',
-    finder_arg_names => [ 'develop_finder' ],
-    default_finders  => [ ':ExtraTestFiles' ],
-  },
 );
 
-#pod =attr finder
-#pod
-#pod This is the name of a L<FileFinder|Dist::Zilla::Role::FileFinder>
-#pod whose files will be scanned to determine runtime prerequisites.  It
-#pod may be specified multiple times.  The default value is
-#pod C<:InstallModules> and C<:ExecFiles>.
-#pod
-#pod =attr test_finder
-#pod
-#pod Just like C<finder>, but for test-phase prerequisites.  The default
-#pod value is C<:TestFiles>.
-#pod
-#pod =attr configure_finder
-#pod
-#pod Just like C<finder>, but for configure-phase prerequisites.  There is
-#pod no default value; AutoPrereqs will not determine configure-phase
-#pod prerequisites unless you set configure_finder.
-#pod
-#pod =attr develop_finder
-#pod
-#pod Just like C<finder>, but for develop-phase prerequisites.  The default value
-#pod is C<:ExtraTestFiles>.
-#pod
-#pod =cut
-
+use Moose::Util::TypeConstraints 'enum';
 use namespace::autoclean;
 
 #pod =head1 SYNOPSIS
@@ -79,6 +38,40 @@ use namespace::autoclean;
 #pod     encoding = bytes
 #pod     match    = ^t/data/
 #pod
+#pod =attr finder
+#pod
+#pod This is the name of a L<FileFinder|Dist::Zilla::Role::FileFinder>
+#pod whose files will be scanned to determine runtime prerequisites.  It
+#pod may be specified multiple times.  The default value is
+#pod C<:InstallModules> and C<:ExecFiles>.
+#pod
+#pod =attr test_finder
+#pod
+#pod Just like C<finder>, but for test-phase prerequisites.  The default
+#pod value is C<:TestFiles>.
+#pod
+#pod =attr configure_finder
+#pod
+#pod Just like C<finder>, but for configure-phase prerequisites.  There is
+#pod no default value; AutoPrereqs will not determine configure-phase
+#pod prerequisites unless you set configure_finder.
+#pod
+#pod =attr develop_finder
+#pod
+#pod Just like C<finder>, but for develop-phase prerequisites.  The default value
+#pod is C<:ExtraTestFiles>.
+#pod
+#pod =attr skips
+#pod
+#pod This is an arrayref of regular expressions, derived from all the 'skip' lines
+#pod in the configuration.  Any module names matching any of these regexes will not
+#pod be registered as prerequisites.
+#pod
+#pod =attr relationship
+#pod
+#pod The relationship used for the registered prerequisites. The default value is
+#pod 'requires'; other options are 'recommends' and 'suggests'.
+#pod
 #pod =attr extra_scanners
 #pod
 #pod This is an arrayref of scanner names (as expected by L<Perl::PrereqScanner>).
@@ -91,12 +84,6 @@ use namespace::autoclean;
 #pod L<Perl::PrereqScanner>, which means that it will replace the default list
 #pod of scanners.
 #pod
-#pod =attr skips
-#pod
-#pod This is an arrayref of regular expressions, derived from all the 'skip' lines
-#pod in the configuration.  Any module names matching any of these regexes will not
-#pod be registered as prerequisites.
-#pod
 #pod =head1 SEE ALSO
 #pod
 #pod L<Prereqs|Dist::Zilla::Plugin::Prereqs>, L<Perl::PrereqScanner>.
@@ -107,9 +94,10 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-sub mvp_multivalue_args { qw(extra_scanners scanners skips) }
+sub mvp_multivalue_args { qw(extra_scanners scanners) }
 sub mvp_aliases { return { extra_scanner => 'extra_scanners',
-                           scanner => 'scanners', skip => 'skips' } }
+                           scanner => 'scanners',
+                           relationship => 'type' } }
 
 has extra_scanners => (
   is  => 'ro',
@@ -123,108 +111,43 @@ has scanners => (
   predicate => 'has_scanners',
 );
 
-has skips => (
-  is  => 'ro',
-  isa => 'ArrayRef[Str]',
+
+has _scanner => (
+  is => 'ro',
+  lazy => 1,
+  default => sub {
+    my $self = shift;
+
+    require Perl::PrereqScanner;
+    Perl::PrereqScanner->VERSION('1.016'); # don't skip "lib"
+
+    return Perl::PrereqScanner->new(
+      ($self->has_scanners ? (scanners => $self->scanners) : ()),
+      extra_scanners => $self->extra_scanners,
+    )
+  },
+  init_arg => undef,
 );
 
+has type => (
+  is => 'ro',
+  isa => enum([qw(requires recommends suggests)]),
+  default => 'requires',
+);
+
+sub scan_file_reqs {
+  my ($self, $file) = @_;
+  return $self->_scanner->scan_ppi_document($self->ppi_document_for_file($file))
+}
+
 sub register_prereqs {
   my $self  = shift;
 
-  require Perl::PrereqScanner;
-  Perl::PrereqScanner->VERSION('1.016'); # don't skip "lib"
-  require CPAN::Meta::Requirements;
-  require List::Util;
-  List::Util->VERSION(1.45);  # uniq
+  my $type = $self->type;
 
-  my @modules;
-
-  my $scanner = Perl::PrereqScanner->new(
-    ($self->has_scanners ? (scanners => $self->scanners) : ()),
-    extra_scanners => $self->extra_scanners,
-  );
-
-  # not a hash, because order is important
-  my @sets = (
-    # phase => file finder method
-    [ configure => 'found_configure_files' ], # must come before runtime
-    [ runtime => 'found_files'      ],
-    [ test    => 'found_test_files' ],
-    [ develop => 'found_develop_files' ],
-  );
-
-  my %runtime_final;
-
-  for my $fileset (@sets) {
-    my ($phase, $method) = @$fileset;
-
-    my $req   = CPAN::Meta::Requirements->new;
-    my $files = $self->$method;
-
-    foreach my $file (@$files) {
-      # skip binary files
-      next if $file->is_bytes;
-      # parse only perl files
-      next unless $file->name =~ /\.(?:pm|pl|t|psgi)$/i
-               || $file->content =~ /^#!(?:.*)perl(?:$|\s)/;
-      # RT#76305 skip extra tests produced by ExtraTests plugin
-      next if $file->name =~ m{^t/(?:author|release)-[^/]*\.t$};
-
-      # store module name, to trim it from require list later on
-      my @this_thing = $file->name;
-
-      # t/lib/Foo.pm is treated as providing t::lib::Foo, lib::Foo, and Foo
-      if ($this_thing[0] =~ /^t/) {
-        push @this_thing, ($this_thing[0]) x 2;
-        $this_thing[1] =~ s{^t/}{};
-        $this_thing[2] =~ s{^t/lib/}{};
-      } else {
-        $this_thing[0] =~ s{^lib/}{};
-      }
-      s{\.pm$}{} for @this_thing;
-      s{/}{::}g for @this_thing;
-
-      # this is a bunk heuristic and can still capture strings from pod - the
-      # proper thing to do is grab all packages from Module::Metadata
-      push @this_thing, $file->content =~ /^[^#]*?(?:^|\s)package\s+([^\s;#]+)/mg;
-      push @modules, @this_thing;
-
-      # parse a file, and merge with existing prereqs
-      $self->log_debug([ 'scanning %s for %s prereqs', $file->name, $phase ]);
-      my $file_req = $scanner->scan_ppi_document(
-        $self->ppi_document_for_file($file)
-      );
-
-      $req->add_requirements($file_req);
-    }
-
-    # remove prereqs from skiplist
-    for my $skip (@{ $self->skips || [] }) {
-      my $re   = qr/$skip/;
-
-      foreach my $k ($req->required_modules) {
-        $req->clear_requirement($k) if $k =~ $re;
-      }
-    }
-
-    # remove prereqs shipped with current dist
-    $self->log_debug([ 'excluding local packages: %s', sub { join(', ', List::Util::uniq @modules) } ]);
-    $req->clear_requirement($_) for @modules;
-
-    $req->clear_requirement($_) for qw(Config DB Errno NEXT Pod::Functions); # never indexed
-
-    # we're done, return what we've found
-    my %got = %{ $req->as_string_hash };
-    if ($phase eq 'runtime') {
-      %runtime_final = %got;
-    } else {
-      # do not test-require things required for runtime
-      delete $got{$_} for
-        grep { exists $got{$_} and $runtime_final{$_} ge $got{$_} }
-        keys %runtime_final;
-    }
-
-    $self->zilla->register_prereqs({ phase => $phase }, %got);
+  my $reqs_by_phase = $self->scan_prereqs;
+  while (my ($phase, $reqs) = each %$reqs_by_phase) {
+    $self->zilla->register_prereqs({ phase => $phase, type => $type }, %$reqs);
   }
 }
 
@@ -243,7 +166,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 SYNOPSIS
 
@@ -297,6 +220,17 @@ prerequisites unless you set configure_finder.
 Just like C<finder>, but for develop-phase prerequisites.  The default value
 is C<:ExtraTestFiles>.
 
+=head2 skips
+
+This is an arrayref of regular expressions, derived from all the 'skip' lines
+in the configuration.  Any module names matching any of these regexes will not
+be registered as prerequisites.
+
+=head2 relationship
+
+The relationship used for the registered prerequisites. The default value is
+'requires'; other options are 'recommends' and 'suggests'.
+
 =head2 extra_scanners
 
 This is an arrayref of scanner names (as expected by L<Perl::PrereqScanner>).
@@ -309,12 +243,6 @@ If present, it will be passed as the C<scanners> parameter to
 L<Perl::PrereqScanner>, which means that it will replace the default list
 of scanners.
 
-=head2 skips
-
-This is an arrayref of regular expressions, derived from all the 'skip' lines
-in the configuration.  Any module names matching any of these regexes will not
-be registered as prerequisites.
-
 =head1 SEE ALSO
 
 L<Prereqs|Dist::Zilla::Plugin::Prereqs>, L<Perl::PrereqScanner>.
@@ -325,7 +253,7 @@ This plugin was originally contributed by Jerome Quelin.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
