@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaYAML;
 # ABSTRACT: produce a META.yml
-$Dist::Zilla::Plugin::MetaYAML::VERSION = '5.044';
+$Dist::Zilla::Plugin::MetaYAML::VERSION = '5.045';
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
@@ -117,7 +117,7 @@ Dist::Zilla::Plugin::MetaYAML - produce a META.yml
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 DESCRIPTION
 
@@ -158,7 +158,7 @@ L<CPAN::Meta::Spec>, L<YAML>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
