@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::BeforeArchive;
 # ABSTRACT: something that runs before the archive file is built
-$Dist::Zilla::Role::BeforeArchive::VERSION = '5.044';
+$Dist::Zilla::Role::BeforeArchive::VERSION = '5.045';
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::BeforeArchive - something that runs before the archive file i
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 DESCRIPTION
 
@@ -38,7 +38,7 @@ called before the archive is actually built.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
