@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::Chrome;
 # ABSTRACT: something that provides a user interface for Dist::Zilla
-$Dist::Zilla::Role::Chrome::VERSION = '5.044';
+$Dist::Zilla::Role::Chrome::VERSION = '5.045';
 use Moose::Role;
 
 use namespace::autoclean;
@@ -25,11 +25,11 @@ Dist::Zilla::Role::Chrome - something that provides a user interface for Dist::Z
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
