@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::ShareDir;
 # ABSTRACT: something that picks a directory to install as shared files
-$Dist::Zilla::Role::ShareDir::VERSION = '5.044';
+$Dist::Zilla::Role::ShareDir::VERSION = '5.045';
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -26,11 +26,11 @@ Dist::Zilla::Role::ShareDir - something that picks a directory to install as sha
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
