@@ -1,6 +1,6 @@
 package Dist::Zilla::Types;
 # ABSTRACT: dzil-specific type library
-$Dist::Zilla::Types::VERSION = '5.044';
+$Dist::Zilla::Types::VERSION = '5.045';
 use namespace::autoclean;
 
 #pod =head1 OVERVIEW
@@ -13,7 +13,10 @@ use namespace::autoclean;
 #pod
 #pod =cut
 
-use MooseX::Types -declare => [qw(License OneZero YesNoStr ReleaseStatus)];
+use MooseX::Types -declare => [qw(
+  License OneZero YesNoStr ReleaseStatus 
+  _Filename
+)];
 use MooseX::Types::Moose qw(Str Int);
 
 subtype License, as class_type('Software::License');
@@ -26,6 +29,10 @@ subtype ReleaseStatus, as Str, where { /\A(?:stable|testing|unstable)\z/ };
 
 coerce OneZero, from YesNoStr, via { /\Ay/i ? 1 : 0 };
 
+subtype _Filename, as Str,
+  where   { $_ !~ qr/(?:\x{0a}|\x{0b}|\x{0c}|\x{0d}|\x{85}|\x{2028}|\x{2029})/ },
+  message { "Filename contains a newline or other vertical whitespace" };
+
 1;
 
 __END__
@@ -40,7 +47,7 @@ Dist::Zilla::Types - dzil-specific type library
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 OVERVIEW
 
@@ -52,7 +59,7 @@ that's what you want.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
