@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::Util::AuthorDeps;
 # ABSTRACT: Utils for listing your distribution's author dependencies
-$Dist::Zilla::Util::AuthorDeps::VERSION = '5.044';
+$Dist::Zilla::Util::AuthorDeps::VERSION = '5.045';
 use Dist::Zilla::Util;
 use Path::Tiny;
 use List::Util 1.45 ();
@@ -72,14 +72,16 @@ sub extract_author_deps {
   my @packages;
   while (<$fh>) {
     chomp;
-    next unless /\A\s*;\s*authordep\s*(\S+)\s*(?:=\s*(.+))?\s*\z/;
+    next unless /\A\s*;\s*authordep\s*(\S+)\s*(?:=\s*([^;]+))?\s*/;
+    my $module = $1;
     my $ver = defined $2 ? $2 : "0";
+    $ver =~ s/\s+$//;
     # Any "; authordep " is inserted at the beginning of the list
     # in the file order so the user can control the order of at least a part of
     # the plugin list
-    push @packages, $1;
+    push @packages, $module;
     # And added to the requirements so we can use it later
-    $reqs->add_string_requirement($1 => $ver);
+    $reqs->add_string_requirement($module => $ver);
   }
 
   my $vermap = $reqs->as_string_hash;
@@ -108,8 +110,7 @@ sub extract_author_deps {
           : (! Class::Load::try_load_class($_, ($vermap->{$_} ? {-version => $vermap->{$_}} : ())))
         : 1
       }
-    List::Util::uniq
-    @packages;
+    List::Util::uniq(@packages);
 
   return \@final;
 }
@@ -128,11 +129,11 @@ Dist::Zilla::Util::AuthorDeps - Utils for listing your distribution's author dep
 
 =head1 VERSION
 
-version 5.044
+version 5.045
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
